spoon.routing

Package spoon :: Package routing |
[hide private]
[frames] | no frames]

# Package routing

source code

Submodules | [hide private]
spoon.routing.meshrouter: Mesh Routing, this is the protocol by which an ad-hoc network of nodes can be created and how messages may be passed between them.

Classes | [hide private]
`` | NetMessage NetMessage is the protocol unit for the networking component of spoon.
`` | RoutingProtocolError
`` | NodeUnreachable Raised when trying to send to a node that is not currently reachable.
`` | MeshRouter This class handles LMTYPE_NETWORK messages and LMTYPE_NETWORK_PROTO messages.

Variables | [hide private]
`` | __module__ = `'spoon'`

Variables Details | [hide private]

    ### __module__ None Value:
        'spoon'